/*
 * Copyright (c) 2011 ScientiaMobile, Inc., VA, USA
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.cache;

import java.util.Map;

import org.apache.commons.collections.MapUtils;
import org.apache.commons.collections.map.LRUMap;

/**
 * CacheProvider {@link LRUMap} implementation.
 * 
 * <p>
 * The cached items are stored using LRUMap. LRUMap is a map using LRU algorithm to evict items.
 * </p>
 * 
 * @author WURFL-PRO SRL, Rome, Italy
 * @version $Id: LRUMapCacheProvider.java 1045 2009-03-09 15:52:53Z filippo.deluca $
 */
public class LRUMapCacheProvider implements CacheProvider {

	/** The {@link LRUMap} instance */
	private Map cache;
	
	

	/**
	 * Constructor by LRUMap parameters. To more detail look at LRUMap documentation.
	 * 
	 * @param maxSize
	 *            The max size of cache.
	 * @param scanUntilRemovable
	 *            scan until a removeable entry is found, default false.
	 * @see LRUMap#LRUMap(int, boolean)
	 */
	public LRUMapCacheProvider(int maxSize, boolean scanUntilRemovable) {
		this.cache = MapUtils.synchronizedMap(new LRUMap(maxSize, scanUntilRemovable));
	
	}

	/**
	 * Constructor by maxSize parameter.
	 * 
	 * @param maxSize
	 *            The max size of cache.
	 * @see LRUMap#LRUMap(int)
	 */
	public LRUMapCacheProvider(int maxSize) {
		this.cache = MapUtils.synchronizedMap(new LRUMap(maxSize));
	}

	/**
	 * Default constructor.
	 */
	public LRUMapCacheProvider() {
		this.cache =  MapUtils.synchronizedMap(new LRUMap());
	}

	public void clear() {
		cache.clear();
	}

	public Object get(Object key) {
		return cache.get(key);
	}

	public void put(Object key, Object value) {
		cache.put(key, value);
	}

}
