/*
 * Copyright (c) 2011 ScientiaMobile, Inc., VA, USA
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.request;

import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;
import net.sourceforge.wurfl.core.request.normalizer.generic.BabelFishNormalizer;
import net.sourceforge.wurfl.core.request.normalizer.generic.BlackBerryNormalizer;
import net.sourceforge.wurfl.core.request.normalizer.generic.UPLinkNormalizer;
import net.sourceforge.wurfl.core.request.normalizer.generic.VodafoneNormalizer;
import net.sourceforge.wurfl.core.request.normalizer.generic.YesWAPNormalizer;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * UserAgentNormalizerFactory default implementation.
 * 
 * <p>
 * Build a UserAgentNormalizerChain with the WURFL UserAgentNormalizers.
 * </p>
 * 
 * @author WURFL-PRO SRL, Rome, Italy
 * @version $Id: DefaultUserAgentNormalizerFactory.java 1045 2009-03-09 15:52:53Z filippo.deluca $
 */
public class DefaultUserAgentNormalizerFactory implements UserAgentNormalizerFactory {

	/** Log */
	private static final Log log = LogFactory.getLog(DefaultUserAgentNormalizerFactory.class);

	/**
	 * {@inheritDoc}
	 * 
	 * @return UserAgentNormalizerChain
	 */
	public UserAgentNormalizer create() {
		
		log.debug("Creating UserAgentNormalizerChain...");

		UserAgentNormalizerChain chain = new UserAgentNormalizerChain();
		chain.add(new VodafoneNormalizer());
		chain.add(new BlackBerryNormalizer());
		chain.add(new UPLinkNormalizer());
		chain.add(new YesWAPNormalizer());
		chain.add(new BabelFishNormalizer());
		
		return chain;
	}

}
