/*
 * Copyright (c) 2011 ScientiaMobile, Inc., VA, USA
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.request.normalizer.generic;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;

/**
 * YesWAP UserAgentNormalizer.
 * 
 * <p>
 * Remove the YesWAP from user-agent.
 * </p>
 * 
 * @author WURFL-PRO SRL, Rome, Italy
 * @version $Id: YesWAPNormalizer.java 1045 2009-03-09 15:52:53Z filippo.deluca $
 */
public class YesWAPNormalizer implements UserAgentNormalizer {

	/** YesWAP regex pattern */
	private static final Pattern yesWapPattern = Pattern
			.compile("\\s*Mozilla/4\\.0 \\(YesWAP mobile phone proxy\\)");

	/**
	 * Replace the "YesWAP mobile phone proxy" with "".
	 */
	public String normalize(String userAgent) {

		String normalizedUserAgent = userAgent;

		Matcher matcher = yesWapPattern.matcher(userAgent);
		if (matcher.find()) {
			normalizedUserAgent = matcher.replaceAll("");
		}

		return normalizedUserAgent;
	}

}
